require 'uu/os/rest/dto'
require 'uu/os/uesuri'
require 'uu/finman/financialtransaction/financial_transaction_dto'

# Module Unicorn Universe
module UU

  # Module Finman
  module Finman

    # Module of finman Financial transaction
    module FinancialTransaction

      # DTO for get attributes command of payment.
      class FastPaymentAttributes < FinancialTransactionDTO

        # URI of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # URI of meta artifact of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :meta_artifact_uri

        # Name of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Code of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Description of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of role competent for the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :competent_role_uri

        # URI of container of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :location_uri

        # URI of organizational unit of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :organizational_unit_uri

        # Security level of the financial transaction.
        # @param [String, UU::OS::Artifact::SecurityLevel]
        # @return [UU::OS::Artifact::SecurityLevel]
        attr_accessor :security_level

        # Creation stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :creation_stamp

        # Creation time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :creation_time

        # Modification stamp of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :modification_stamp

        # Modification time of the financial transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :modification_time

        # Version of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :version

        # Name of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_name

        # Comment of current state of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :state_comment

        # Type of current state of the financial transaction.
        # @param [UU::OS::Artifact::ArtifactStateType]
        # @return [UU::OS::Artifact::ArtifactStateType]
        attr_accessor :state_type

        # Flag of width of sheets of the financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :width

        # URI of the icon of the financial transaction.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :icon_uri

        # UESURI of the entity type of the artifact
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :entity_type_uri

        # Amount of the Financial Transaction without vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_without_vat

        # Amount of the Financial Transaction with vat.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :amount_with_vat

        # Constant symbol.
        # @param [String]
        # @return [String]
        attr_accessor :constant_symbol

        # UESURI of Contract.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :contract_uri

        # Code of cost item.
        # @param [String]
        # @return [String]
        attr_accessor :cost_item_code

        # Number of credit account.
        # @param [String]
        # @return [String]
        attr_accessor :credit_account_number

        # UESURI of credit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_account_uri

        # UESURI of credit business case from opposite territory.
        # Set only for interterritorial payments
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_from_opposite_territory

        # UESURI of the credit business case
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_business_case_uri

        # Description for credit side.
        # @param [String]
        # @return [String]
        attr_accessor :credit_description

        # UESURI of credit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :credit_financial_category_uri

        # Credit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :credit_vat_date

        # Number of debit account.
        # @param [String]
        # @return [String]
        attr_accessor :debit_account_number

        # UESURI of debit account artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_account_uri

        # UESURI of debit business case from opposite territory.
        # Set only for interterritorial payments
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_from_opposite_territory

        # UESURI of the debit business case.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_business_case_uri

        # Description for debit side.
        # @param [String]
        # @return [String]
        attr_accessor :debit_description

        # Close after creation
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :close_after_creation

        # UESURI of debit financial category.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :debit_financial_category_uri

        # Debit vat date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :debit_vat_date

        # Date the payment is due to be paid.
        # @param [String, Time]
        # @return [String]
        attr_accessor :due_date

        # Date the payment is expected to be payed to.
        # @param [String, Time]
        # @return [String]
        attr_accessor :expected_pay_date

        # Amount in other side currency, specified by user
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :explicit_amount

        # Type of financial transaction. Item from enumeration {FinancialTransactionType}
        # Possible values: CASH or NONCASH
        # @param [FinancialTransactionType]
        # @return [FinancialTransactionType]
        attr_accessor :financial_transaction_type

        # Class of financial transaction (specifies if it is Payment, Transfer, Expost payment or Credit note)
        # @param [FinancialTransactionClass]
        # @return [FinancialTransactionClass]
        attr_accessor :financial_transaction_class

        # Code of income item.
        # @param [String]
        # @return [String]
        attr_accessor :income_item_code

        # Invoice number of financial transaction.
        # @param [String]
        # @return [String]
        attr_accessor :invoice_number

        # UESURI of payment copy artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :interterritorial_payment_copy_uri

        # UESURI of payment original artifact.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :interterritorial_payment_original_uri

        # Indicates that payment was automatically requested acceptance after creation.
        # @param [TrueClass, FalseClass]
        # @return [TrueClass, FalseClass]
        attr_accessor :is_ready_for_acceptance

        # Pay date of the transaction.
        # @param [String, Time]
        # @return [String]
        attr_accessor :pay_date

        # Date of invoicing to the counterparty.
        # @param [String, Time]
        # @return [String]
        attr_accessor :protocol_date

        # Probability of payment realization in %.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :realization_probability

        # Specific symbol.
        # @param [String]
        # @return [String]
        attr_accessor :specific_symbol

        # Variable symbol.
        # @param [String]
        # @return [String]
        attr_accessor :variable_symbol

        # Vat rate.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :vat_rate

        # Code of credit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :credit_side_currency

        # Code of debit side currency.
        # @param [String]
        # @return [String]
        attr_accessor :debit_side_currency

        # Code of transaction currency.
        # @param [String]
        # @return [String]
        attr_accessor :transaction_currency

        # Specifies which side controls transaction (CREDIT or DEBIT).
        # @param [ControlSide]
        # @return [ControlSide]
        attr_accessor :control_side

        # Related links(URI, label) in JSON format.
        # @param [String]
        # @return [String]
        attr_accessor :related_links

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def meta_artifact_uri
          attributes[:metaArtifactUri]
        end

        def meta_artifact_uri=(val)
          if val
            attributes[:metaArtifactUri] = UU::OS::UESURI.new(val)
          else
            attributes[:metaArtifactUri] = nil
          end
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def competent_role_uri
          attributes[:competentRoleUri]
        end

        def competent_role_uri=(val)
          if val
            attributes[:competentRoleUri] = UU::OS::UESURI.new(val)
          else
            attributes[:competentRoleUri] = nil
          end
        end

        def location_uri
          attributes[:locationUri]
        end

        def location_uri=(val)
          if val
            attributes[:locationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:locationUri] = nil
          end
        end

        def organizational_unit_uri
          attributes[:organizationalUnitUri]
        end

        def organizational_unit_uri=(val)
          if val
            attributes[:organizationalUnitUri] = UU::OS::UESURI.new(val)
          else
            attributes[:organizationalUnitUri] = nil
          end
        end

        def security_level
          attributes[:securityLevel]
        end

        def security_level=(val)
          attributes[:securityLevel] = val
        end

        def creation_stamp
          attributes[:creationStamp]
        end

        def creation_stamp=(val)
          attributes[:creationStamp] = val
        end

        def creation_time
          attributes[:creationTime]
        end

        def creation_time=(val)
          attributes[:creationTime] = val
        end

        def modification_stamp
          attributes[:modificationStamp]
        end

        def modification_stamp=(val)
          attributes[:modificationStamp] = val
        end

        def modification_time
          attributes[:modificationTime]
        end

        def modification_time=(val)
          attributes[:modificationTime] = val
        end

        def version
          attributes[:version]
        end

        def version=(val)
          attributes[:version] = val
        end

        def state_name
          attributes[:stateName]
        end

        def state_name=(val)
          attributes[:stateName] = val
        end

        def state_comment
          attributes[:stateComment]
        end

        def state_comment=(val)
          attributes[:stateComment] = val
        end

        def state_type
          attributes[:stateType]
        end

        def state_type=(val)
          attributes[:stateType] = val
        end

        def width
          attributes[:width]
        end

        def width=(val)
          attributes[:width] = val
        end

        def icon_uri
          attributes[:iconUri]
        end

        def icon_uri=(val)
          if val
            attributes[:iconUri] = UU::OS::UESURI.new(val)
          else
            attributes[:iconUri] = nil
          end
        end

        def entity_type_uri
          attributes[:entityTypeUri]
        end

        def entity_type_uri=(val)
          if val
            attributes[:entityTypeUri] = UU::OS::UESURI.new(val)
          else
            attributes[:entityTypeUri] = nil
          end
        end

        def amount_without_vat
          attributes[:amountWithoutVat]
        end

        def amount_without_vat=(val)
          attributes[:amountWithoutVat] = val
        end

        def amount_with_vat
          attributes[:amountWithVat]
        end

        def amount_with_vat=(val)
          attributes[:amountWithVat] = val
        end

        def constant_symbol
          attributes[:constantSymbol]
        end

        def constant_symbol=(val)
          attributes[:constantSymbol] = val
        end

        def contract_uri
          attributes[:contractUri]
        end

        def contract_uri=(val)
          if val
            attributes[:contractUri] = UU::OS::UESURI.new(val)
          else
            attributes[:contractUri] = nil
          end
        end

        def cost_item_code
          attributes[:costItemCode]
        end

        def cost_item_code=(val)
          attributes[:costItemCode] = val
        end

        def credit_account_number
          attributes[:creditAccountNumber]
        end

        def credit_account_number=(val)
          attributes[:creditAccountNumber] = val
        end

        def credit_account_uri
          attributes[:creditAccountUri]
        end

        def credit_account_uri=(val)
          if val
            attributes[:creditAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditAccountUri] = nil
          end
        end

        def credit_business_case_from_opposite_territory
          attributes[:creditBusinessCaseFromOppositeTerritory]
        end

        def credit_business_case_from_opposite_territory=(val)
          attributes[:creditBusinessCaseFromOppositeTerritory] = val
        end

        def credit_business_case_uri
          attributes[:creditBusinessCaseUri]
        end

        def credit_business_case_uri=(val)
          if val
            attributes[:creditBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditBusinessCaseUri] = nil
          end
        end

        def credit_description
          attributes[:creditDescription]
        end

        def credit_description=(val)
          attributes[:creditDescription] = val
        end

        def credit_financial_category_uri
          attributes[:creditFinancialCategoryUri]
        end

        def credit_financial_category_uri=(val)
          if val
            attributes[:creditFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:creditFinancialCategoryUri] = nil
          end
        end

        def credit_vat_date
          attributes[:creditVatDate]
        end

        def credit_vat_date=(val)
          attributes[:creditVatDate] = val
        end

        def debit_account_number
          attributes[:debitAccountNumber]
        end

        def debit_account_number=(val)
          attributes[:debitAccountNumber] = val
        end

        def debit_account_uri
          attributes[:debitAccountUri]
        end

        def debit_account_uri=(val)
          if val
            attributes[:debitAccountUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitAccountUri] = nil
          end
        end

        def debit_business_case_from_opposite_territory
          attributes[:debitBusinessCaseFromOppositeTerritory]
        end

        def debit_business_case_from_opposite_territory=(val)
          attributes[:debitBusinessCaseFromOppositeTerritory] = val
        end

        def debit_business_case_uri
          attributes[:debitBusinessCaseUri]
        end

        def debit_business_case_uri=(val)
          if val
            attributes[:debitBusinessCaseUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitBusinessCaseUri] = nil
          end
        end

        def close_after_creation
          attributes[:closeAfterCreation]
        end

        def close_after_creation=(val)
          attributes[:closeAfterCreation] = val
        end

        def debit_description
          attributes[:debitDescription]
        end

        def debit_description=(val)
          attributes[:debitDescription] = val
        end

        def debit_financial_category_uri
          attributes[:debitFinancialCategoryUri]
        end

        def debit_financial_category_uri=(val)
          if val
            attributes[:debitFinancialCategoryUri] = UU::OS::UESURI.new(val)
          else
            attributes[:debitFinancialCategoryUri] = nil
          end
        end

        def debit_vat_date
          attributes[:debitVatDate]
        end

        def debit_vat_date=(val)
          attributes[:debitVatDate] = val
        end

        def due_date
          attributes[:dueDate]
        end

        def due_date=(val)
          attributes[:dueDate] = val
        end

        def expected_pay_date
          attributes[:expectedPayDate]
        end

        def expected_pay_date=(val)
          attributes[:expectedPayDate] = val
        end

        def explicit_amount
          attributes[:explicitAmount]
        end

        def explicit_amount=(val)
          attributes[:explicitAmount] = val
        end

        def financial_transaction_type
          attributes[:financialTransactionType]
        end

        def financial_transaction_type=(val)
          attributes[:financialTransactionType] = val
        end

        def financial_transaction_class
          attributes[:financialTransactionClass]
        end

        def financial_transaction_class=(val)
          attributes[:financialTransactionClass] = val
        end

        def income_item_code
          attributes[:incomeItemCode]
        end

        def income_item_code=(val)
          attributes[:incomeItemCode] = val
        end

        def invoice_number
          attributes[:invoiceNumber]
        end

        def invoice_number=(val)
          attributes[:invoiceNumber] = val
        end

        def interterritorial_payment_copy_uri
          attributes[:interterritorialPaymentCopyUri]
        end

        def interterritorial_payment_copy_uri=(val)
          if val
            attributes[:interterritorialPaymentCopyUri] = UU::OS::UESURI.new(val)
          else
            attributes[:interterritorialPaymentCopyUri] = nil
          end
        end

        def interterritorial_payment_original_uri
          attributes[:interterritorialPaymentOriginalUri]
        end

        def interterritorial_payment_original_uri=(val)
          if val
            attributes[:interterritorialPaymentOriginalUri] = UU::OS::UESURI.new(val)
          else
            attributes[:interterritorialPaymentOriginalUri] = nil
          end
        end

        def is_ready_for_acceptance
          attributes[:isReadyForAcceptance]
        end

        def is_ready_for_acceptance=(val)
          attributes[:isReadyForAcceptance] = val
        end

        def pay_date
          attributes[:payDate]
        end

        def pay_date=(val)
          attributes[:payDate] = val
        end

        def protocol_date
          attributes[:protocolDate]
        end

        def protocol_date=(val)
          attributes[:protocolDate] = val
        end

        def realization_probability
          attributes[:realizationProbability]
        end

        def realization_probability=(val)
          attributes[:realizationProbability] = val
        end

        def specific_symbol
          attributes[:specificSymbol]
        end

        def specific_symbol=(val)
          attributes[:specificSymbol] = val
        end

        def variable_symbol
          attributes[:variableSymbol]
        end

        def variable_symbol=(val)
          attributes[:variableSymbol] = val
        end

        def vat_rate
          attributes[:vatRate]
        end

        def vat_rate=(val)
          attributes[:vatRate] = val
        end

        def credit_side_currency
          attributes[:creditSideCurrency]
        end

        def credit_side_currency=(val)
          attributes[:creditSideCurrency] = val
        end

        def debit_side_currency
          attributes[:debitSideCurrency]
        end

        def debit_side_currency=(val)
          attributes[:debitSideCurrency] = val
        end

        def transaction_currency
          attributes[:transactionCurrency]
        end

        def transaction_currency=(val)
          attributes[:transactionCurrency] = val
        end

        def control_side
          attributes[:controlSide]
        end

        def control_side=(val)
          attributes[:controlSide] = val
        end

        def related_links
          attributes[:relatedLinks]
        end

        def related_links=(val)
          attributes[:relatedLinks] = val
        end

      end
    end
  end
end
